==> eam-wshub-proxyclient-11.4-12-sources.jar: net/datastream/schemas/mp_fields/GLREFERENCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour GLREFERENCEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="GLREFERENCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PROCESSCODE" type="{http://schemas.datastream.net/MP_fields}CODE20_Type"/>
 *         &lt;element name="SCHEDULINGGROUP" type="{http://schemas.datastream.net/MP_fields}CODE20_Type"/>
 *         &lt;element name="JECATEGORY" type="{http://schemas.datastream.net/MP_fields}CODE25_Type"/>
 *         &lt;element name="GLFSETOFBOOKSID" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *         &lt;element name="JESOURCE" type="{http://schemas.datastream.net/MP_fields}CODE25_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GLREFERENCEID_Type", propOrder = {
    "processcode",
    "schedulinggroup",
    "jecategory",
    "glfsetofbooksid",
    "jesource"
})
public class GLREFERENCEID_Type {

    @XmlElement(name = "PROCESSCODE", required = true)
    protected String processcode;
    @XmlElement(name = "SCHEDULINGGROUP", required = true)
    protected String schedulinggroup;
    @XmlElement(name = "JECATEGORY", required = true)
    protected String jecategory;
    @XmlElement(name = "GLFSETOFBOOKSID")
    protected long glfsetofbooksid;
    @XmlElement(name = "JESOURCE", required = true)
    protected String jesource;

    /**
     * Obtient la valeur de la propriété processcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROCESSCODE() {
        return processcode;
    }

    /**
     * Définit la valeur de la propriété processcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROCESSCODE(String value) {
        this.processcode = value;
    }

    /**
     * Obtient la valeur de la propriété schedulinggroup.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSCHEDULINGGROUP() {
        return schedulinggroup;
    }

    /**
     * Définit la valeur de la propriété schedulinggroup.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSCHEDULINGGROUP(String value) {
        this.schedulinggroup = value;
    }

    /**
     * Obtient la valeur de la propriété jecategory.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJECATEGORY() {
        return jecategory;
    }

    /**
     * Définit la valeur de la propriété jecategory.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJECATEGORY(String value) {
        this.jecategory = value;
    }

    /**
     * Obtient la valeur de la propriété glfsetofbooksid.
     * 
     */
    public long getGLFSETOFBOOKSID() {
        return glfsetofbooksid;
    }

    /**
     * Définit la valeur de la propriété glfsetofbooksid.
     * 
     */
    public void setGLFSETOFBOOKSID(long value) {
        this.glfsetofbooksid = value;
    }

    /**
     * Obtient la valeur de la propriété jesource.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJESOURCE() {
        return jesource;
    }

    /**
     * Définit la valeur de la propriété jesource.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJESOURCE(String value) {
        this.jesource = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/GLREFERENCEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for GLREFERENCEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="GLREFERENCEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="PROCESSCODE" type="{http://schemas.datastream.net/MP_fields}CODE20_Type"/>
 *         &lt;element name="SCHEDULINGGROUP" type="{http://schemas.datastream.net/MP_fields}CODE20_Type"/>
 *         &lt;element name="JECATEGORY" type="{http://schemas.datastream.net/MP_fields}CODE25_Type"/>
 *         &lt;element name="GLFSETOFBOOKSID" type="{http://www.w3.org/2001/XMLSchema}long"/>
 *         &lt;element name="JESOURCE" type="{http://schemas.datastream.net/MP_fields}CODE25_Type"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "GLREFERENCEID_Type", propOrder = {
    "processcode",
    "schedulinggroup",
    "jecategory",
    "glfsetofbooksid",
    "jesource"
})
public class GLREFERENCEID_Type {

    @XmlElement(name = "PROCESSCODE", required = true)
    protected String processcode;
    @XmlElement(name = "SCHEDULINGGROUP", required = true)
    protected String schedulinggroup;
    @XmlElement(name = "JECATEGORY", required = true)
    protected String jecategory;
    @XmlElement(name = "GLFSETOFBOOKSID")
    protected long glfsetofbooksid;
    @XmlElement(name = "JESOURCE", required = true)
    protected String jesource;

    /**
     * Gets the value of the processcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPROCESSCODE() {
        return processcode;
    }

    /**
     * Sets the value of the processcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPROCESSCODE(String value) {
        this.processcode = value;
    }

    /**
     * Gets the value of the schedulinggroup property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSCHEDULINGGROUP() {
        return schedulinggroup;
    }

    /**
     * Sets the value of the schedulinggroup property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSCHEDULINGGROUP(String value) {
        this.schedulinggroup = value;
    }

    /**
     * Gets the value of the jecategory property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJECATEGORY() {
        return jecategory;
    }

    /**
     * Sets the value of the jecategory property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJECATEGORY(String value) {
        this.jecategory = value;
    }

    /**
     * Gets the value of the glfsetofbooksid property.
     * 
     */
    public long getGLFSETOFBOOKSID() {
        return glfsetofbooksid;
    }

    /**
     * Sets the value of the glfsetofbooksid property.
     * 
     */
    public void setGLFSETOFBOOKSID(long value) {
        this.glfsetofbooksid = value;
    }

    /**
     * Gets the value of the jesource property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getJESOURCE() {
        return jesource;
    }

    /**
     * Sets the value of the jesource property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setJESOURCE(String value) {
        this.jesource = value;
    }

}
